@@ -5,7 +5,7 @@ from functools import wraps
 import flask
 import yaml
 
-from .builders import LogTextBuilder
+from .builders import builder_factory, LogBuilder
 
 
 class FlaskLogging:
@@ -27,7 +27,7 @@ class FlaskLogging:
         """
         return self._conf
 
-    def init_app(self, app, builder=LogTextBuilder()):
+    def init_app(self, app, builder=None):
         """
 
         :param app: Flask app instance
@@ -40,7 +40,14 @@ class FlaskLogging:
         self.set_default_config(app)
         self.set_request_id(app)
 
+        if app.config['LOG_BUILDER']:
+            builder = builder_factory(app.config['LOG_BUILDER'])
+
+        if type(builder) is str:
+            builder = builder_factory(builder)
+
         if builder:
+            assert isinstance(builder, LogBuilder)
             app.before_request_funcs.setdefault(None, []).append(builder.dump_request)
             app.after_request_funcs.setdefault(None, []).append(builder.dump_response)
 
@@ -50,7 +57,8 @@ class FlaskLogging:
                     self._conf = yaml.safe_load(f)
             except (OSError, IOError, yaml.YAMLError) as exc:
                 app.logger.exception(exc, stack_info=False)
-        elif app.config['LOGGING']:
+
+        if not self._conf and app.config['LOGGING']:
             self._conf = app.config['LOGGING']
 
         if self._conf:
@@ -89,9 +97,8 @@ class FlaskLogging:
         :return: wrapped function
         """
         if not issubclass(filter_class, logging.Filter):
-            raise ValueError(
-                "'{}' must be subclass of {}".format(filter_class, logging.Filter.__name__)
-            )
+            name = logging.Filter.__name__
+            raise ValueError("'{}' must be subclass of {}".format(filter_class, name))
 
         if not loggers:
             loggers = [None]  # root logger has no name
@@ -119,13 +126,14 @@ class FlaskLogging:
         """
         app.config.setdefault('LOG_FILE_CONF', None)
         app.config.setdefault('LOGGING', None)
+        app.config.setdefault('LOG_BUILDER', None)
         app.config.setdefault('LOG_REQ_HEADERS', [])
         app.config.setdefault('LOG_RESP_HEADERS', [])
         app.config.setdefault('REQUEST_ID_HEADER', 'X-Request-ID')
-        app.config.setdefault('LOG_SKIP_DUMP', not app.config.get('DEBUG'))
+        app.config.setdefault('LOG_SKIP_DUMP', not app.debug)
         app.config.setdefault('LOG_RESP_FORMAT', "{level} STATUS {status} {headers} {body}")
         app.config.setdefault('LOG_REQ_FORMAT', "{address} {method} {scheme} {path} {headers} {body}")
-        app.config.setdefault('LOG_APP_NAME', 'flask')
+        app.config.setdefault('LOG_APP_NAME', app.config.get('APP_NAME') or 'flask')
         app.config.setdefault('LOG_LOGGER_NAME', '{}-{}'.format(
             app.config['LOG_APP_NAME'],
             app.config.get('FLASK_ENV') or 'development'
